@@ -31,14 +31,20 @@ from .partial_emoji import PartialEmoji, _EmojiTag
 from .utils import MISSING, get_slots
 
 if TYPE_CHECKING:
+    from .channel import ChannelType
     from .emoji import Emoji
     from .types.components import (
         ActionRow as ActionRowPayload,
         ButtonComponent as ButtonComponentPayload,
+        ChannelSelectMenu as ChannelSelectMenuPayload,
         Component as ComponentPayload,
+        MentionableSelectMenu as MentionableSelectMenuPayload,
+        RoleSelectMenu as RoleSelectMenuPayload,
         SelectMenu as SelectMenuPayload,
+        SelectMenuBase as SelectMenuBasePayload,
         SelectOption as SelectOptionPayload,
         TextInputComponent as TextInputComponentPayload,
+        UserSelectMenu as UserSelectMenuPayload,
     )
 
 
@@ -62,13 +68,18 @@ class Component:
     - :class:`ActionRow`
     - :class:`Button`
     - :class:`SelectMenu`
+    - :class:`TextInput`
+    - :class:`UserSelectMenu`
+    - :class:`ChannelSelectMenu`
+    - :class:`RoleSelectMenu`
+    - :class:`MentionableSelectMenu`
 
     This class is abstract and cannot be instantiated.
 
     .. versionadded:: 2.0
 
     Attributes
-    ------------
+    ----------
     type: :class:`ComponentType`
         The type of component.
     """
@@ -108,7 +119,7 @@ class ActionRow(Component):
     .. versionadded:: 2.0
 
     Attributes
-    ------------
+    ----------
     type: :class:`ComponentType`
         The type of component.
     children: List[:class:`Component`]
@@ -143,7 +154,7 @@ class Button(Component):
     .. versionadded:: 2.0
 
     Attributes
-    -----------
+    ----------
     style: :class:`.ButtonStyle`
         The style of the button.
     custom_id: Optional[:class:`str`]
@@ -202,12 +213,66 @@ class Button(Component):
         return payload  # type: ignore
 
 
-class SelectMenu(Component):
-    """Represents a select menu from the Discord Bot UI Kit.
+class SelectMenuBase(Component):
+    """Represents a Discord Bot UI Kit Select Menu.
+
+    This is the base class for all select menus.
+
+    .. versionadded:: 2.3
+
+    Attributes
+    ----------
+    custom_id: :class:`str`
+        The ID of the select menu that gets received during an interaction.
+    disabled: :class:`bool`
+        Whether the select menu is disabled or not. Defaults to ``False``.
+    placeholder: Optional[:class:`str`]
+        The placeholder of the select menu, if any.
+    min_values: :class:`int`
+        The minimum number of values that must be chosen. Defaults to 1.
+    max_values: :class:`int`
+        The maximum number of values that can be chosen. Defaults to 1.
+    """
+
+    __slots__: Tuple[str, ...] = (
+        "custom_id",
+        "disabled",
+        "placeholder",
+        "min_values",
+        "max_values",
+    )
+
+    __repr_info__: ClassVar[Tuple[str, ...]] = __slots__
+
+    def __init__(self, data: SelectMenuBasePayload):
+        self.custom_id: str = data["custom_id"]
+        self.disabled: bool = data.get("disabled", False)
+        self.placeholder: Optional[str] = data.get("placeholder")
+        self.min_values: int = data.get("min_values", 1)
+        self.max_values: int = data.get("max_values", 1)
+
+    def to_dict(self) -> SelectMenuBasePayload:
+        payload: SelectMenuBasePayload = {
+            "custom_id": self.custom_id,
+            "disabled": self.disabled,
+            "min_values": self.min_values,
+            "max_values": self.max_values,
+        }
+
+        if self.placeholder:
+            payload["placeholder"] = self.placeholder
+
+        return payload
+
+
+class StringSelectMenu(SelectMenuBase):
+    """Represents a string select menu from the Discord Bot UI Kit.
 
     A select menu is functionally the same as a dropdown, however
     on mobile it renders a bit differently.
 
+    There is an alias for this class called ``SelectMenu``.
+
     .. note::
 
         The user constructible and usable type to create a select menu is
@@ -216,7 +281,7 @@ class SelectMenu(Component):
     .. versionadded:: 2.0
 
     Attributes
-    ------------
+    ----------
     custom_id: Optional[:class:`str`]
         The ID of the select menu that gets received during an interaction.
     placeholder: Optional[:class:`str`]
@@ -230,43 +295,208 @@ class SelectMenu(Component):
     options: List[:class:`SelectOption`]
         A list of options that can be selected in this menu.
     disabled: :class:`bool`
-        Whether the select is disabled or not.
+        Whether the select is disabled or not. Defaults to ``False``.
     """
 
-    __slots__: Tuple[str, ...] = (
-        "custom_id",
-        "placeholder",
-        "min_values",
-        "max_values",
-        "options",
-        "disabled",
-    )
+    __slots__: Tuple[str, ...] = ("options",)
 
     __repr_info__: ClassVar[Tuple[str, ...]] = __slots__
 
     def __init__(self, data: SelectMenuPayload):
+        super().__init__(data)
         self.type = ComponentType.select
-        self.custom_id: str = data["custom_id"]
-        self.placeholder: Optional[str] = data.get("placeholder")
-        self.min_values: int = data.get("min_values", 1)
-        self.max_values: int = data.get("max_values", 1)
         self.options: List[SelectOption] = [
             SelectOption.from_dict(option) for option in data.get("options", [])
         ]
-        self.disabled: bool = data.get("disabled", False)
 
     def to_dict(self) -> SelectMenuPayload:
         payload: SelectMenuPayload = {
             "type": self.type.value,
-            "custom_id": self.custom_id,
-            "min_values": self.min_values,
-            "max_values": self.max_values,
             "options": [op.to_dict() for op in self.options],
-            "disabled": self.disabled,
-        }
+            **super().to_dict(),
+        }  # type: ignore -- fixed in pyright 1.1.278
 
-        if self.placeholder:
-            payload["placeholder"] = self.placeholder
+        return payload
+
+
+SelectMenu = StringSelectMenu
+
+
+class UserSelectMenu(SelectMenuBase):
+    """Represents a user select menu from the Discord Bot UI Kit.
+
+    A user select menu is functionally the same as a dropdown, however
+    on mobile it renders a bit differently.
+
+    .. note::
+
+        The user constructible and usable type to create a select menu is
+        :class:`nextcord.ui.UserSelect` not this one.
+
+    .. versionadded:: 2.3
+
+    Attributes
+    ----------
+    custom_id: Optional[:class:`str`]
+        The ID of the select menu that gets received during an interaction.
+    placeholder: Optional[:class:`str`]
+        The placeholder text that is shown if nothing is selected, if any.
+    min_values: :class:`int`
+        The minimum number of items that must be chosen for this select menu.
+        Defaults to 1 and must be between 1 and 25.
+    max_values: :class:`int`
+        The maximum number of items that must be chosen for this select menu.
+        Defaults to 1 and must be between 1 and 25.
+    disabled: :class:`bool`
+        Whether the select is disabled or not. Defaults to ``False``.
+    """
+
+    __slots__: Tuple[str, ...] = ()
+
+    __repr_info__: ClassVar[Tuple[str, ...]] = __slots__
+
+    def __init__(self, data: UserSelectMenuPayload):
+        super().__init__(data)
+        self.type = ComponentType.user_select
+
+    def to_dict(self) -> UserSelectMenuPayload:
+        payload: UserSelectMenuPayload = {"type": self.type.value, **super().to_dict()}  # type: ignore -- fixed in pyright 1.1.278
+
+        return payload
+
+
+class RoleSelectMenu(SelectMenuBase):
+    """Represents a role select menu from the Discord Bot UI Kit.
+
+    A role select menu is functionally the same as a dropdown, however
+    on mobile it renders a bit differently.
+
+    .. note::
+
+        The user constructible and usable type to create a select menu is
+        :class:`nextcord.ui.RoleSelect` not this one.
+
+    .. versionadded:: 2.3
+
+    Attributes
+    ----------
+    custom_id: Optional[:class:`str`]
+        The ID of the select menu that gets received during an interaction.
+    placeholder: Optional[:class:`str`]
+        The placeholder text that is shown if nothing is selected, if any.
+    min_values: :class:`int`
+        The minimum number of items that must be chosen for this select menu.
+        Defaults to 1 and must be between 1 and 25.
+    max_values: :class:`int`
+        The maximum number of items that must be chosen for this select menu.
+        Defaults to 1 and must be between 1 and 25.
+    disabled: :class:`bool`
+        Whether the select is disabled or not. Defaults to ``False``.
+    """
+
+    __slots__: Tuple[str, ...] = ()
+
+    __repr_info__: ClassVar[Tuple[str, ...]] = __slots__
+
+    def __init__(self, data: RoleSelectMenuPayload):
+        super().__init__(data)
+        self.type = ComponentType.role_select
+
+    def to_dict(self) -> RoleSelectMenuPayload:
+        payload: RoleSelectMenuPayload = {"type": self.type.value, **super().to_dict()}  # type: ignore -- fixed in pyright 1.1.278
+
+        return payload
+
+
+class MentionableSelectMenu(SelectMenuBase):
+    """Represents a mentionable select menu from the Discord Bot UI Kit.
+
+    A mentionable select menu is functionally the same as a dropdown, however
+    on mobile it renders a bit differently.
+
+    .. note::
+
+        The user constructible and usable type to create a select menu is
+        :class:`nextcord.ui.MentionableSelect` not this one.
+
+    .. versionadded:: 2.3
+
+    Attributes
+    ----------
+    custom_id: Optional[:class:`str`]
+        The ID of the select menu that gets received during an interaction.
+    placeholder: Optional[:class:`str`]
+        The placeholder text that is shown if nothing is selected, if any.
+    min_values: :class:`int`
+        The minimum number of items that must be chosen for this select menu.
+        Defaults to 1 and must be between 1 and 25.
+    max_values: :class:`int`
+        The maximum number of items that must be chosen for this select menu.
+        Defaults to 1 and must be between 1 and 25.
+    disabled: :class:`bool`
+        Whether the select is disabled or not. Defaults to ``False``.
+    """
+
+    __slots__: Tuple[str, ...] = ()
+
+    __repr_info__: ClassVar[Tuple[str, ...]] = __slots__
+
+    def __init__(self, data: MentionableSelectMenuPayload):
+        super().__init__(data)
+        self.type = ComponentType.mentionable_select
+
+    def to_dict(self) -> MentionableSelectMenuPayload:
+        payload: MentionableSelectMenuPayload = {"type": self.type.value, **super().to_dict()}  # type: ignore -- fixed in pyright 1.1.278
+
+        return payload
+
+
+class ChannelSelectMenu(SelectMenuBase):
+    """Represents a mentionable select menu from the Discord Bot UI Kit.
+
+    A mentionable select menu is functionally the same as a dropdown, however
+    on mobile it renders a bit differently.
+
+    .. note::
+
+        The user constructible and usable type to create a select menu is
+        :class:`nextcord.ui.ChannelSelect` not this one.
+
+    .. versionadded:: 2.3
+
+    Attributes
+    ----------
+    custom_id: Optional[:class:`str`]
+        The ID of the select menu that gets received during an interaction.
+    placeholder: Optional[:class:`str`]
+        The placeholder text that is shown if nothing is selected, if any.
+    min_values: :class:`int`
+        The minimum number of items that must be chosen for this select menu.
+        Defaults to 1 and must be between 1 and 25.
+    max_values: :class:`int`
+        The maximum number of items that must be chosen for this select menu.
+        Defaults to 1 and must be between 1 and 25.
+    disabled: :class:`bool`
+        Whether the select is disabled or not. Defaults to ``False``.
+    channel_types: List[:class:`ChannelType`]
+        The types of channels that can be selected. If not given, all channel types are allowed.
+    """
+
+    __slots__: Tuple[str, ...] = ("channel_types",)
+
+    __repr_info__: ClassVar[Tuple[str, ...]] = __slots__
+
+    def __init__(self, data: ChannelSelectMenuPayload):
+        super().__init__(data)
+        self.type = ComponentType.channel_select
+        self.channel_types: List[ChannelType] = [
+            ChannelType(t) for t in data.get("channel_types", [])
+        ]
+
+    def to_dict(self) -> ChannelSelectMenuPayload:
+        payload: ChannelSelectMenuPayload = {"type": self.type.value, **super().to_dict()}  # type: ignore -- fixed in pyright 1.1.278
+        if self.channel_types:
+            payload["channel_types"] = [t.value for t in self.channel_types]
 
         return payload
 
@@ -279,7 +509,7 @@ class SelectOption:
     .. versionadded:: 2.0
 
     Attributes
-    -----------
+    ----------
     label: :class:`str`
         The label of the option. This is displayed to users.
         Can only be up to 100 characters.
@@ -313,9 +543,9 @@ class SelectOption:
         emoji: Optional[Union[str, Emoji, PartialEmoji]] = None,
         default: bool = False,
     ) -> None:
-        self.label = label
-        self.value = label if value is MISSING else value
-        self.description = description
+        self.label: str = label
+        self.value: str = label if value is MISSING else value
+        self.description: Optional[str] = description
 
         if emoji is not None:
             if isinstance(emoji, str):
@@ -327,8 +557,8 @@ class SelectOption:
                     f"Expected emoji to be str, Emoji, or PartialEmoji not {emoji.__class__}"
                 )
 
-        self.emoji = emoji
-        self.default = default
+        self.emoji: Optional[PartialEmoji] = emoji
+        self.default: bool = default
 
     def __repr__(self) -> str:
         return (
