@@ -29,7 +29,6 @@ import asyncio
 import datetime
 import itertools
 import sys
-from functools import partial
 from operator import attrgetter
 from typing import TYPE_CHECKING, Any, Dict, List, Literal, Optional, Tuple, Type, TypeVar, Union
 
@@ -50,7 +49,6 @@ __all__ = (
 
 if TYPE_CHECKING:
     from .abc import Snowflake
-    from .asset import Asset
     from .channel import DMChannel, StageChannel, VoiceChannel
     from .flags import PublicUserFlags
     from .guild import Guild
@@ -73,7 +71,7 @@ class VoiceState:
     """Represents a Discord user's voice state.
 
     Attributes
-    ------------
+    ----------
     deaf: :class:`bool`
         Indicates if the user is currently deafened by the guild.
     mute: :class:`bool`
@@ -570,7 +568,7 @@ class Member(abc.Messageable, _UserTag):
         """Checks if the member is mentioned in the specified message.
 
         Parameters
-        -----------
+        ----------
         message: :class:`Message`
             The message to check if you're mentioned in.
 
@@ -648,14 +646,20 @@ class Member(abc.Messageable, _UserTag):
     async def ban(
         self,
         *,
-        delete_message_days: Literal[0, 1, 2, 3, 4, 5, 6, 7] = 1,
+        delete_message_seconds: Optional[int] = None,
+        delete_message_days: Optional[Literal[0, 1, 2, 3, 4, 5, 6, 7]] = None,
         reason: Optional[str] = None,
     ) -> None:
         """|coro|
 
         Bans this member. Equivalent to :meth:`Guild.ban`.
         """
-        await self.guild.ban(self, reason=reason, delete_message_days=delete_message_days)
+        await self.guild.ban(
+            self,
+            reason=reason,
+            delete_message_seconds=delete_message_seconds,
+            delete_message_days=delete_message_days,
+        )
 
     async def unban(self, *, reason: Optional[str] = None) -> None:
         """|coro|
@@ -689,7 +693,7 @@ class Member(abc.Messageable, _UserTag):
         .. versionadded:: 2.0
 
         Parameters
-        -----------
+        ----------
         timeout: Optional[Union[:class:`~datetime.datetime`, :class:`~datetime.timedelta`]]
             The time until the member should not be timed out.
             Set this to None to disable their timeout.
@@ -741,7 +745,7 @@ class Member(abc.Messageable, _UserTag):
             The newly member is now optionally returned, if applicable.
 
         Parameters
-        -----------
+        ----------
         nick: Optional[:class:`str`]
             The member's new nickname. Use ``None`` to remove the nickname.
         mute: :class:`bool`
@@ -767,14 +771,14 @@ class Member(abc.Messageable, _UserTag):
             .. versionadded:: 2.0
 
         Raises
-        -------
+        ------
         Forbidden
             You do not have the proper permissions to the action requested.
         HTTPException
             The operation failed.
 
         Returns
-        --------
+        -------
         Optional[:class:`.Member`]
             The newly updated member, if applicable. This is only returned
             when certain fields are updated.
@@ -859,7 +863,7 @@ class Member(abc.Messageable, _UserTag):
         .. versionadded:: 1.7
 
         Raises
-        -------
+        ------
         Forbidden
             You do not have the proper permissions to the action requested.
         HTTPException
@@ -892,7 +896,7 @@ class Member(abc.Messageable, _UserTag):
             Can now pass ``None`` to kick a member from voice.
 
         Parameters
-        -----------
+        ----------
         channel: Optional[:class:`VoiceChannel`]
             The new voice channel to move the member to.
             Pass ``None`` to kick them from voice.
@@ -912,7 +916,7 @@ class Member(abc.Messageable, _UserTag):
         This raises the same exceptions as :meth:`edit`.
 
         Parameters
-        -----------
+        ----------
         reason: Optional[:class:`str`]
             The reason for doing this action. Shows up on the audit log.
         """
@@ -930,7 +934,7 @@ class Member(abc.Messageable, _UserTag):
         of roles than the highest role of the member.
 
         Parameters
-        -----------
+        ----------
         \*roles: :class:`abc.Snowflake`
             An argument list of :class:`abc.Snowflake` representing a :class:`Role`
             to give to the member.
@@ -942,7 +946,7 @@ class Member(abc.Messageable, _UserTag):
             state of the cache.
 
         Raises
-        -------
+        ------
         Forbidden
             You do not have permissions to add these roles.
         HTTPException
@@ -950,7 +954,7 @@ class Member(abc.Messageable, _UserTag):
         """
 
         if not atomic:
-            new_roles: list[Snowflake] = utils._unique(
+            new_roles: list[Snowflake] = utils.unique(
                 Object(id=r.id) for s in (self.roles[1:], roles) for r in s
             )
             await self.edit(roles=new_roles, reason=reason)
@@ -973,7 +977,7 @@ class Member(abc.Messageable, _UserTag):
         of roles than the highest role of the member.
 
         Parameters
-        -----------
+        ----------
         \*roles: :class:`abc.Snowflake`
             An argument list of :class:`abc.Snowflake` representing a :class:`Role`
             to remove from the member.
@@ -985,7 +989,7 @@ class Member(abc.Messageable, _UserTag):
             state of the cache.
 
         Raises
-        -------
+        ------
         Forbidden
             You do not have permissions to remove these roles.
         HTTPException
@@ -1016,12 +1020,12 @@ class Member(abc.Messageable, _UserTag):
         .. versionadded:: 2.0
 
         Parameters
-        -----------
+        ----------
         role_id: :class:`int`
             The ID to search for.
 
         Returns
-        --------
+        -------
         Optional[:class:`Role`]
             The role or ``None`` if not found in the member's roles.
         """
