@@ -28,7 +28,7 @@ from typing import TYPE_CHECKING, Any, Optional, Union
 
 from .enums import VoiceRegion
 from .guild import Guild
-from .utils import MISSING, _bytes_to_base64_data, _obj_to_base64_data, parse_time
+from .utils import MISSING, obj_to_base64_data, parse_time
 
 __all__ = ("Template",)
 
@@ -96,7 +96,7 @@ class Template:
     .. versionadded:: 1.4
 
     Attributes
-    -----------
+    ----------
     code: :class:`str`
         The template code.
     uses: :class:`int`
@@ -210,7 +210,7 @@ class Template:
             The guild created. This is not the same guild that is
             added to cache.
         """
-        icon_base64 = await _obj_to_base64_data(icon)
+        icon_base64 = await obj_to_base64_data(icon)
 
         region = region or VoiceRegion.us_west
         region_value = region.value
@@ -234,7 +234,7 @@ class Template:
             The template is no longer edited in-place, instead it is returned.
 
         Raises
-        -------
+        ------
         HTTPException
             Editing the template failed.
         Forbidden
@@ -243,7 +243,7 @@ class Template:
             This template does not exist.
 
         Returns
-        --------
+        -------
         :class:`Template`
             The newly edited template.
         """
@@ -270,14 +270,14 @@ class Template:
             The template is no longer edited in-place, instead it is returned.
 
         Parameters
-        ------------
+        ----------
         name: :class:`str`
             The template's new name.
         description: Optional[:class:`str`]
             The template's new description.
 
         Raises
-        -------
+        ------
         HTTPException
             Editing the template failed.
         Forbidden
@@ -286,7 +286,7 @@ class Template:
             This template does not exist.
 
         Returns
-        --------
+        -------
         :class:`Template`
             The newly edited template.
         """
@@ -311,7 +311,7 @@ class Template:
         .. versionadded:: 1.7
 
         Raises
-        -------
+        ------
         HTTPException
             Editing the template failed.
         Forbidden
