@@ -25,11 +25,14 @@ DEALINGS IN THE SOFTWARE.
 
 from typing import List, Literal, Optional, TypedDict, Union
 
+from typing_extensions import NotRequired
+
 from .snowflake import Snowflake
 from .threads import ThreadArchiveDuration, ThreadMember, ThreadMetadata
 from .user import PartialUser
 
 OverwriteType = Literal[0, 1]
+SortOrderType = Literal[0, 1]
 
 
 class PermissionOverwrite(TypedDict):
@@ -59,72 +62,58 @@ class PartialChannel(_BaseChannel):
     type: ChannelType
 
 
-class _TextChannelOptional(TypedDict, total=False):
-    topic: str
-    last_message_id: Optional[Snowflake]
-    last_pin_timestamp: str
-    rate_limit_per_user: int
-    default_auto_archive_duration: ThreadArchiveDuration
-
-
-class TextChannel(_BaseGuildChannel, _TextChannelOptional):
+class TextChannel(_BaseGuildChannel):
     type: Literal[0]
+    topic: NotRequired[str]
+    last_message_id: NotRequired[Optional[Snowflake]]
+    last_pin_timestamp: NotRequired[str]
+    rate_limit_per_user: NotRequired[int]
+    default_auto_archive_duration: NotRequired[ThreadArchiveDuration]
 
 
-class _ForumChannelOptional(TypedDict, total=False):
-    topic: str
-    last_message_id: Optional[Snowflake]
-    rate_limit_per_user: int
-    default_auto_archive_duration: ThreadArchiveDuration
-
-
-class ForumChannel(_BaseGuildChannel, _ForumChannelOptional):
+class ForumChannel(_BaseGuildChannel):
     type: Literal[15]
+    topic: NotRequired[str]
+    last_message_id: NotRequired[Optional[Snowflake]]
+    rate_limit_per_user: NotRequired[int]
+    default_auto_archive_duration: NotRequired[ThreadArchiveDuration]
+    default_sort_order: Optional[SortOrderType]
 
 
-class NewsChannel(_BaseGuildChannel, _TextChannelOptional):
+class NewsChannel(_BaseGuildChannel):
     type: Literal[5]
+    topic: NotRequired[str]
+    last_message_id: NotRequired[Optional[Snowflake]]
+    last_pin_timestamp: NotRequired[str]
+    rate_limit_per_user: NotRequired[int]
+    default_auto_archive_duration: NotRequired[ThreadArchiveDuration]
 
 
 VideoQualityMode = Literal[1, 2]
 
 
-class _VoiceChannelOptional(TypedDict, total=False):
-    last_message_id: Optional[Snowflake]
-    rtc_region: Optional[str]
-    video_quality_mode: VideoQualityMode
-
-
-class VoiceChannel(_BaseGuildChannel, _VoiceChannelOptional):
+class VoiceChannel(_BaseGuildChannel):
     type: Literal[2]
     bitrate: int
     user_limit: int
+    last_message_id: NotRequired[Optional[Snowflake]]
+    rtc_region: NotRequired[Optional[str]]
+    video_quality_mode: NotRequired[VideoQualityMode]
 
 
 class CategoryChannel(_BaseGuildChannel):
     type: Literal[4]
 
 
-class _StageChannelOptional(TypedDict, total=False):
-    rtc_region: Optional[str]
-    topic: str
-
-
-class StageChannel(_BaseGuildChannel, _StageChannelOptional):
+class StageChannel(_BaseGuildChannel):
     type: Literal[13]
     bitrate: int
     user_limit: int
+    rtc_region: NotRequired[Optional[str]]
+    topic: NotRequired[str]
 
 
-class _ThreadChannelOptional(TypedDict, total=False):
-    member: ThreadMember
-    owner_id: Snowflake
-    rate_limit_per_user: int
-    last_message_id: Optional[Snowflake]
-    last_pin_timestamp: str
-
-
-class ThreadChannel(_BaseChannel, _ThreadChannelOptional):
+class ThreadChannel(_BaseChannel):
     type: Literal[10, 11, 12]
     guild_id: Snowflake
     parent_id: Snowflake
@@ -135,6 +124,8 @@ class ThreadChannel(_BaseChannel, _ThreadChannelOptional):
     message_count: int
     member_count: int
     thread_metadata: ThreadMetadata
+    member: NotRequired[ThreadMember]
+    last_pin_timestamp: NotRequired[str]
 
 
 GuildChannel = Union[
